@@ -1,25 +1,53 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+# Copyright (c) 2011 Boris Pohler <boris@pohlers-web.de>
+
+# Permission is hereby granted, free of charge, to any person obtaining a
+# copy of this software and associated documentation files (the "Software"),
+# to deal in the Software without restriction, including without limitation
+# the rights to use, copy, modify, merge, publish, distribute, sublicense,
+# and/or sell copies of the Software, and to permit persons to whom the
+# Software is furnished to do so, subject to the following conditions:
+
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+# DEALINGS IN THE SOFTWARE.
+
+
 # Importe
 import sys
 import os
 import pickle
-from PyQt4 import uic
-from PyQt4.QtGui import QMainWindow, QApplication, QInputDialog, QMenu, QCursor, QMessageBox
+from PyQt4.uic import loadUi
+from PyQt4.QtGui import QMainWindow, QApplication, QInputDialog, QMenu, \
+                        QCursor, QMessageBox, QDialog
 from PyQt4.QtCore import QObject, QString, QTimer, QTime, Qt
-
+from PyQt4.QtMaemo5 import *
 
 class Zeitkonto():
     def __init__(self, name = "Projekt"):
         self.name = name
         self.zeit = 0
 
+class Dialog_Zeit(QDialog):
+    def __init__(self,parent):
+        QDialog.__init__(self,parent=None)
+        self.ui = loadUi("dialog_zeit.ui")
+        #self.ui.show()
+
 class Fenster_Zeitkonto(QMainWindow):
     def __init__(self):
         QMainWindow.__init__(self)
         # Oberfläche abbilden     
-        self.ui = uic.loadUi("zeitkonto.ui")
+        self.ui = loadUi("zeitkonto.ui")
         self.ui.show()
  
         self.zeitkonten_liste= [Zeitkonto()]
@@ -78,7 +106,6 @@ class Fenster_Zeitkonto(QMainWindow):
         if self.zeitkonten_liste:
             self.zeile = zeile
             self.konto = self.zeitkonten_liste[zeile]
-            self.ui.label_name.setText(self.konto.name)
             self.zeit0 = self.konto.zeit
             msecs = self.zeit0
             msecs /= 1000
@@ -89,13 +116,14 @@ class Fenster_Zeitkonto(QMainWindow):
             hours = msecs
             timestring = '%02d:%02d:%02d' % (hours, min, sec)
             self.ui.label_zeit.setText(timestring)
+            self.ui.label_name.setText(self.konto.name)
         else:
             self.ui.label_zeit.setText("00:00:00")
             self.ui.label_name.setText("")
         
     def zeitkonto_anlegen(self):
-        text, ok = QInputDialog.getText(self, 'Zeitkonto anlegen', 
-                                              'Gib dem Konto einen Namen:')
+        text, ok = QInputDialog.getText(self, u'Zeitkonto anlegen', 
+                                              u'Gib dem Konto einen Namen:')
         if ok:
             konto = Zeitkonto(text)
             self.zeitkonten_liste.append(konto)
@@ -112,10 +140,35 @@ class Fenster_Zeitkonto(QMainWindow):
             self.liste_speichern()
 
     def konto_name_bearbeiten(self):
-        QMessageBox.about(self, u"Kommt noch!",u"""<p>Diese Funktion ist noch nicht implementiert.""")
+        text, ok = QInputDialog.getText(self, u'Name ändern', 
+                                              u'Gib den neuen Namen ein:')
+        if ok:
+            self.zeitkonten_liste[self.zeile].name = text
+            self.anzeige_aktualisieren()
+            self.liste_speichern()
 
     def konto_zeit_bearbeiten(self):
-        QMessageBox.about(self, u"Kommt noch!",u"""<p>Diese Funktion ist noch nicht implementiert.""")
+        self.dialog = QDialog(self)
+        self.dialog.ui = loadUi("dialog_zeit.ui") 
+	if self.dialog.ui.exec_() == 1:
+           stunden = self.dialog.ui.stunden.value()
+           minuten = self.dialog.ui.minuten.value()
+           sekunden = self.dialog.ui.sekunden.value()
+           self.konto.zeit = stunden * 3600000 \
+                           + minuten * 60000 \
+                           + sekunden * 1000
+           self.zeit0 = self.konto.zeit
+           msecs = self.zeit0
+           msecs /= 1000
+           sec = msecs % 60
+           msecs /= 60
+           min = msecs % 60
+           msecs /= 60
+           hours = msecs
+           timestring = '%02d:%02d:%02d' % (hours, min, sec)
+           self.ui.label_zeit.setText(timestring)
+           #self.ui.label_name.setText(self.konto.name)
+           
 
     def liste_laden(self):
         f = open("/home/user/MyDocs/.zeitkonto/zeitkonten.db",'r')
@@ -138,7 +191,9 @@ class Fenster_Zeitkonto(QMainWindow):
         self.ui.listWidget.show()
         self.ui.label_2.show()
         timestring = self.ui.label_zeit.text().split(QString(':'))
-        zeit0 = int(timestring[0])*3600000 + int(timestring[1])*60000 +int(timestring[2])*1000
+        zeit0 = int(timestring[0])*3600000 \
+              + int(timestring[1])*60000 \
+              + int(timestring[2])*1000
         self.konto.zeit = zeit0
         self.ui.knopf_start.setEnabled(True)
         self.timer.stop()
@@ -156,13 +211,14 @@ class Fenster_Zeitkonto(QMainWindow):
         self.ui.label_zeit.setText(timestring)
 
     def zeige_ueber(self):
-        QMessageBox.about(self, u"Über das Programm",u"""<b>Zeitkonten</b>
-                                    <p>Das Programm bietet die Möglichkeit, Zeitkonten für
-                                    verschiedene Aufgaben anzulegen und die verwendete Zeit
-                                    dafür zu stoppen. 
-                                    Mit einem langen Druck auf die Liste öffnet sich ein Menü.
-                                    <p>Wünsche oder Kritik bitte an 
-                                    <p>boris@pohlers-web.de""")
+        QMessageBox.about(self, 
+                          u"Über das Programm",u"""<b>Zeitkonten</b>
+                          <p>Das Programm bietet die Möglichkeit, Zeitkonten für
+                             verschiedene Aufgaben anzulegen und die verwendete Zeit
+                             dafür zu stoppen. 
+                             Mit einem langen Druck auf die Liste öffnet sich ein Menü.
+                          <p>Wünsche oder Kritik bitte an 
+                          <p>boris@pohlers-web.de""")
 
 # Starten des Programms
 if __name__=="__main__":
